CREATE SCHEMA IF NOT EXISTS `rtd`;

CREATE TABLE IF NOT EXISTS `rtd`.`real_time_formulas` (
    `ID` INTEGER NOT NULL AUTO_INCREMENT,
    `TABLE_SCHEMA` VARCHAR(128) NOT NULL,
    `TABLE_NAME` VARCHAR(128) NOT NULL,
    `COLUMN_NAME` VARCHAR(128) NOT NULL,
    `RTD_FORMULA` VARCHAR(255) NULL,
    `IS_DISABLED` TINYINT NULL,
  PRIMARY KEY (`ID`)
);

ALTER TABLE `rtd`.`real_time_formulas`
    ADD UNIQUE INDEX `ix_real_time_formulas_schema_name_column_name`
    USING BTREE (
       `TABLE_SCHEMA`,
       `TABLE_NAME`,
       `COLUMN_NAME`
    );


CREATE TABLE IF NOT EXISTS `rtd`.`real_time_tables` (
    `ID` INTEGER NOT NULL AUTO_INCREMENT,
    `TABLE_SCHEMA` VARCHAR(128) NOT NULL,
    `TABLE_NAME` VARCHAR(128) NOT NULL,
    `LOAD_CODE` VARCHAR(2000) NULL,
    `IS_HISTORY` TINYINT NULL,
    `IS_DISABLED` TINYINT NULL,
    `TIME_ZONE` VARCHAR(50) NULL,
    `RTD_INSTANCE_NAME` VARCHAR(50) NULL,
  PRIMARY KEY (`ID`)
);

ALTER TABLE `rtd`.`real_time_tables`
    ADD UNIQUE INDEX `ix_realtimetables_schema_name`
    USING BTREE (
       `TABLE_SCHEMA`,
       `TABLE_NAME`
    );
    
CREATE TABLE IF NOT EXISTS `rtd`.`es_stock_list` (
    `CODE` VARCHAR(50) NOT NULL,
  PRIMARY KEY (`CODE`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`es_historical_prices` (
    `SYMBOL` VARCHAR(50) NOT NULL,
    `DATE` DATE NOT NULL,
    `TIME` TIME NULL,
    `LAST` DOUBLE NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `BID_SIZE` INTEGER NULL,
    `ASK_SIZE` INTEGER NULL,
    `OPEN` DOUBLE NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `VOLUME` BIGINT NULL,
    `OPEN_INT` INTEGER NULL,
    `TRADE_PRICE` DOUBLE NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`SYMBOL`, `DATE`)
);


INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('rtd', 'es_historical_prices', 'SELECT CODE FROM rtd.es_stock_list', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_historical_prices', 'CODE', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_historical_prices', 'SYMBOL', '=RTD("esrtd",,[CODE],"Symbol")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_historical_prices', 'DATE', '=Date()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_historical_prices', 'TIME', '=RTD("esrtd",,[CODE],"Time")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_historical_prices', 'LAST', '=RTD("esrtd",,[CODE],"Last")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_historical_prices', 'TRADE_PRICE', '=RTD("esrtd",,[CODE],"TradePrice")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_historical_prices', 'CHANGE', '=RTD("esrtd",,[CODE],"Change")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_historical_prices', 'PERCENT_CHANGE', '=RTD("esrtd",,[CODE],"% Change")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_historical_prices', 'BID', '=RTD("esrtd",,[CODE],"Bid")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_historical_prices', 'ASK', '=RTD("esrtd",,[CODE],"Ask")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_historical_prices', 'BID_SIZE', '=RTD("esrtd",,[CODE],"Bid Size")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_historical_prices', 'ASK_SIZE', '=RTD("esrtd",,[CODE],"Ask Size")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_historical_prices', 'OPEN', '=RTD("esrtd",,[CODE],"Open")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_historical_prices', 'HIGH', '=RTD("esrtd",,[CODE],"High")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_historical_prices', 'LOW', '=RTD("esrtd",,[CODE],"Low")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_historical_prices', 'VOLUME', '=RTD("esrtd",,[CODE],"Volume")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_historical_prices', 'OPEN_INT', '=RTD("esrtd",,[CODE],"OpenInt")', NULL);

CREATE TABLE IF NOT EXISTS `rtd`.`es_last_stock_quotes` (
    `SYMBOL` VARCHAR(50) NOT NULL,
    `DATE` DATE NULL,
    `TIME` TIME NULL,
    `LAST` DOUBLE NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `BID_SIZE` INTEGER NULL,
    `ASK_SIZE` INTEGER NULL,
    `OPEN` DOUBLE NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `VOLUME` BIGINT NULL,
    `OPEN_INT` INTEGER NULL,
    `TRADE_PRICE` DOUBLE NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`SYMBOL`)
);


INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('rtd', 'es_last_stock_quotes', 'SELECT CODE FROM rtd.es_stock_list', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_last_stock_quotes', 'CODE', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_last_stock_quotes', 'SYMBOL', '=RTD("esrtd",,[CODE],"Symbol")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_last_stock_quotes', 'DATE', '=Date()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_last_stock_quotes', 'TIME', '=RTD("esrtd",,[CODE],"Time")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_last_stock_quotes', 'LAST', '=RTD("esrtd",,[CODE],"Last")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_last_stock_quotes', 'TRADE_PRICE', '=RTD("esrtd",,[CODE],"TradePrice")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_last_stock_quotes', 'CHANGE', '=RTD("esrtd",,[CODE],"Change")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_last_stock_quotes', 'PERCENT_CHANGE', '=RTD("esrtd",,[CODE],"% Change")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_last_stock_quotes', 'BID', '=RTD("esrtd",,[CODE],"Bid")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_last_stock_quotes', 'ASK', '=RTD("esrtd",,[CODE],"Ask")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_last_stock_quotes', 'BID_SIZE', '=RTD("esrtd",,[CODE],"Bid Size")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_last_stock_quotes', 'ASK_SIZE', '=RTD("esrtd",,[CODE],"Ask Size")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_last_stock_quotes', 'OPEN', '=RTD("esrtd",,[CODE],"Open")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_last_stock_quotes', 'HIGH', '=RTD("esrtd",,[CODE],"High")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_last_stock_quotes', 'LOW', '=RTD("esrtd",,[CODE],"Low")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_last_stock_quotes', 'VOLUME', '=RTD("esrtd",,[CODE],"Volume")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_last_stock_quotes', 'OPEN_INT', '=RTD("esrtd",,[CODE],"OpenInt")', NULL);

CREATE TABLE IF NOT EXISTS `rtd`.`es_stock_quotes_ticks` (
    `ID` INTEGER NOT NULL AUTO_INCREMENT,
    `SYMBOL` VARCHAR(50) NOT NULL,
    `DATE` DATE NULL,
    `TIME` TIME NULL,
    `LAST` DOUBLE NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `BID_SIZE` INTEGER NULL,
    `ASK_SIZE` INTEGER NULL,
    `OPEN` DOUBLE NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `VOLUME` BIGINT NULL,
    `OPEN_INT` INTEGER NULL,
    `TRADE_PRICE` DOUBLE NULL,
  PRIMARY KEY (`ID`)
);


INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('rtd', 'es_stock_quotes_ticks', 'SELECT CODE FROM rtd.es_stock_list', 1, 1, 'Eastern Standard Time', NULL);

INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_ticks', 'ID', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_ticks', 'CODE', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_ticks', 'SYMBOL', '=RTD("esrtd",,[CODE],"Symbol")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_ticks', 'DATE', '=Date()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_ticks', 'TIME', '=RTD("esrtd",,[CODE],"Time")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_ticks', 'LAST', '=RTD("esrtd",,[CODE],"Last")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_ticks', 'TRADE_PRICE', '=RTD("esrtd",,[CODE],"TradePrice")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_ticks', 'CHANGE', '=RTD("esrtd",,[CODE],"Change")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_ticks', 'PERCENT_CHANGE', '=RTD("esrtd",,[CODE],"% Change")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_ticks', 'BID', '=RTD("esrtd",,[CODE],"Bid")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_ticks', 'ASK', '=RTD("esrtd",,[CODE],"Ask")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_ticks', 'BID_SIZE', '=RTD("esrtd",,[CODE],"Bid Size")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_ticks', 'ASK_SIZE', '=RTD("esrtd",,[CODE],"Ask Size")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_ticks', 'OPEN', '=RTD("esrtd",,[CODE],"Open")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_ticks', 'HIGH', '=RTD("esrtd",,[CODE],"High")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_ticks', 'LOW', '=RTD("esrtd",,[CODE],"Low")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_ticks', 'VOLUME', '=RTD("esrtd",,[CODE],"Volume")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_ticks', 'OPEN_INT', '=RTD("esrtd",,[CODE],"OpenInt")', NULL);

CREATE TABLE IF NOT EXISTS `rtd`.`es_stock_quotes_time` (
    `SYMBOL` VARCHAR(50) NOT NULL,
    `DATE` DATE NOT NULL,
    `TIME` TIME NOT NULL,
    `LAST` DOUBLE NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `BID_SIZE` INTEGER NULL,
    `ASK_SIZE` INTEGER NULL,
    `OPEN` DOUBLE NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `VOLUME` BIGINT NULL,
    `OPEN_INT` INTEGER NULL,
    `TRADE_PRICE` DOUBLE NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY
(
    `SYMBOL`,
    `DATE`,
    `TIME`
)
);


INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('rtd', 'es_stock_quotes_time', 'SELECT CODE FROM rtd.es_stock_list', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_time', 'CODE', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_time', 'SYMBOL', '=RTD("esrtd",,[CODE],"Symbol")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_time', 'DATE', '=Date()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_time', 'TIME', '=RTD("esrtd",,[CODE],"Time")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_time', 'LAST', '=RTD("esrtd",,[CODE],"Last")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_time', 'TRADE_PRICE', '=RTD("esrtd",,[CODE],"TradePrice")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_time', 'CHANGE', '=RTD("esrtd",,[CODE],"Change")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_time', 'PERCENT_CHANGE', '=RTD("esrtd",,[CODE],"% Change")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_time', 'BID', '=RTD("esrtd",,[CODE],"Bid")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_time', 'ASK', '=RTD("esrtd",,[CODE],"Ask")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_time', 'BID_SIZE', '=RTD("esrtd",,[CODE],"Bid Size")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_time', 'ASK_SIZE', '=RTD("esrtd",,[CODE],"Ask Size")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_time', 'OPEN', '=RTD("esrtd",,[CODE],"Open")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_time', 'HIGH', '=RTD("esrtd",,[CODE],"High")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_time', 'LOW', '=RTD("esrtd",,[CODE],"Low")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_time', 'VOLUME', '=RTD("esrtd",,[CODE],"Volume")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'es_stock_quotes_time', 'OPEN_INT', '=RTD("esrtd",,[CODE],"OpenInt")', NULL);

