CREATE SCHEMA IF NOT EXISTS `rtd`;

CREATE TABLE IF NOT EXISTS `rtd`.`real_time_formulas` (
    `ID` INTEGER NOT NULL AUTO_INCREMENT,
    `TABLE_SCHEMA` VARCHAR(128) NOT NULL,
    `TABLE_NAME` VARCHAR(128) NOT NULL,
    `COLUMN_NAME` VARCHAR(128) NOT NULL,
    `RTD_FORMULA` VARCHAR(255) NULL,
    `IS_DISABLED` TINYINT NULL,
  PRIMARY KEY (`ID`)
);

ALTER TABLE `rtd`.`real_time_formulas`
    ADD UNIQUE INDEX `ix_real_time_formulas_schema_name_column_name`
    USING BTREE (
       `TABLE_SCHEMA`,
       `TABLE_NAME`,
       `COLUMN_NAME`
    );


CREATE TABLE IF NOT EXISTS `rtd`.`real_time_tables` (
    `ID` INTEGER NOT NULL AUTO_INCREMENT,
    `TABLE_SCHEMA` VARCHAR(128) NOT NULL,
    `TABLE_NAME` VARCHAR(128) NOT NULL,
    `LOAD_CODE` VARCHAR(2000) NULL,
    `IS_HISTORY` TINYINT NULL,
    `IS_DISABLED` TINYINT NULL,
    `TIME_ZONE` VARCHAR(50) NULL,
    `RTD_INSTANCE_NAME` VARCHAR(50) NULL,
  PRIMARY KEY (`ID`)
);

ALTER TABLE `rtd`.`real_time_tables`
    ADD UNIQUE INDEX `ix_realtimetables_schema_name`
    USING BTREE (
       `TABLE_SCHEMA`,
       `TABLE_NAME`
    );
    
CREATE TABLE IF NOT EXISTS `rtd`.`tos_stock_list` (
    `SYMBOL` VARCHAR(50) NOT NULL,
  PRIMARY KEY (`SYMBOL`)
);

INSERT INTO `rtd`.`tos_stock_list` (`SYMBOL`) VALUES ('SPY');

CREATE TABLE IF NOT EXISTS `rtd`.`tos_option_list` (
    `CODE` VARCHAR(50) NOT NULL,
  PRIMARY KEY (`CODE`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`tos_historical_option_data` (
    `CODE` VARCHAR(50) NOT NULL,
    `DATE` DATE NOT NULL,
    `TIME` TIME NULL,
    `DESCRIPTION` VARCHAR(255) NULL,
    `LAST` DOUBLE NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `LAST_SIZE` SMALLINT NULL,
    `LAST_X` CHAR(1) NULL,
    `MARK` DOUBLE NULL,
    `MARK_CHANGE` DOUBLE NULL,
    `MARK_PERCENT_CHANGE` DOUBLE NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `BID_SIZE` SMALLINT NULL,
    `ASK_SIZE` SMALLINT NULL,
    `BID_ASK_SIZE` VARCHAR(50) NULL,
    `BID_X` CHAR(1) NULL,
    `ASK_X` CHAR(1) NULL,
    `OPEN` DOUBLE NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `CLOSE` DOUBLE NULL,
    `VOLUME` INTEGER NULL,
    `OPEN_INT` INTEGER NULL,
    `IMPLIED_VOL` DOUBLE NULL,
    `DELTA` DOUBLE NULL,
    `GAMMA` DOUBLE NULL,
    `THETA` DOUBLE NULL,
    `VEGA` DOUBLE NULL,
    `RHO` DOUBLE NULL,
    `EXTRINSIC` DOUBLE NULL,
    `INTRINSIC` DOUBLE NULL,
    `PROBABILITY_ITM` DOUBLE NULL,
    `PROBABILITY_OTM` DOUBLE NULL,
    `PROBABILITY_TOUCH` DOUBLE NULL,
    `COVERED_RETURN` DOUBLE NULL,
    `MAX_COVERED_RETURN` DOUBLE NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`CODE`, `DATE`)
);


INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('rtd', 'tos_historical_option_data', 'SELECT CODE FROM rtd.tos_option_list', NULL, NULL, 'Eastern Standard Time', NULL);

INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`) VALUES ('rtd', 'tos_historical_option_data', 'CODE');
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'DATE', '=Date()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'TIME', '=Time()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'DESCRIPTION', '=TOS|DESCRIPTION!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'LAST', '=TOS|LAST!''[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'CHANGE', '=TOS|NET_CHANGE!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'PERCENT_CHANGE', '=TOS|PERCENT_CHANGE!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'LAST_SIZE', '=TOS|LAST_SIZE!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'LAST_X', '=TOS|LX!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'MARK', '=TOS|MARK!''[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'MARK_CHANGE', '=TOS|MARK_CHANGE!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'MARK_PERCENT_CHANGE', '=TOS|MARK_PERCENT_CHANGE!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'BID', '=TOS|BID!''[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'ASK', '=TOS|ASK!''[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'BID_SIZE', '=TOS|BID_SIZE!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'ASK_SIZE', '=TOS|ASK_SIZE!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'BID_ASK_SIZE', '=TOS|BA_SIZE!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'BID_X', '=TOS|BX!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'ASK_X', '=TOS|AX!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'OPEN', '=TOS|OPEN!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'HIGH', '=TOS|HIGH!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'LOW', '=TOS|LOW!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'CLOSE', '=TOS|Close!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'VOLUME', '=TOS|VOLUME!''[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'OPEN_INT', '=TOS|OPEN_INT!''[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'IMPLIED_VOL', '=TOS|IMPL_VOL!''[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'DELTA', '=TOS|DELTA!''[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'GAMMA', '=TOS|GAMMA!''[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'THETA', '=TOS|THETA!''[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'VEGA', '=TOS|VEGA!''[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'RHO', '=TOS|RHO!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'EXTRINSIC', '=TOS|EXTRINSIC!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'INTRINSIC', '=TOS|INTRINSIC!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'PROBABILITY_ITM', '=TOS|PROB_OF_EXPIRING!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'PROBABILITY_OTM', '=TOS|PROB_OTM!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'PROBABILITY_TOUCH', '=TOS|PROB_OF_TOUCHING!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'COVERED_RETURN', '=TOS|COVERED_RETURN!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_option_data', 'MAX_COVERED_RETURN', '=TOS|MAX_COVERED_RETURN!''[CODE]''', 1);

CREATE TABLE IF NOT EXISTS `rtd`.`tos_historical_prices` (
    `SYMBOL` VARCHAR(50) NOT NULL,
    `DATE` DATE NOT NULL,
    `TIME` TIME NULL,
    `DESCRIPTION` VARCHAR(255) NULL,
    `LAST` DOUBLE NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `LAST_SIZE` INTEGER NULL,
    `LAST_X` CHAR(1) NULL,
    `MARK` DOUBLE NULL,
    `MARK_CHANGE` DOUBLE NULL,
    `MARK_PERCENT_CHANGE` DOUBLE NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `BID_SIZE` INTEGER NULL,
    `ASK_SIZE` INTEGER NULL,
    `BID_ASK_SIZE` VARCHAR(255) NULL,
    `BID_X` CHAR(1) NULL,
    `ASK_X` CHAR(1) NULL,
    `STRENGTH_METER` VARCHAR(255) NULL,
    `OPEN` DOUBLE NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `CLOSE` DOUBLE NULL,
    `VOLUME` BIGINT NULL,
    `OPEN_INT` INTEGER NULL,
    `IMPLIED_VOL` DOUBLE NULL,
    `VOL_INDEX` DOUBLE NULL,
    `FRONT_VOL` DOUBLE NULL,
    `BACK_VOL` DOUBLE NULL,
    `WEIGHTED_BACK_VOL` DOUBLE NULL,
    `VOL_DIFF` DOUBLE NULL,
    `PUT_CALL_RATIO` DOUBLE NULL,
    `CALL_VOLUME_INDEX` DOUBLE NULL,
    `PUT_VOLUME_INDEX` DOUBLE NULL,
    `OPTION_VOLUME_INDEX` DOUBLE NULL,
    `FRONT_EXPECTED_MOVE` DOUBLE NULL,
    `BACK_EXPECTED_MOVE` DOUBLE NULL,
    `EXPECTED_MOVE_DIFF` DOUBLE NULL,
    `BETA` DOUBLE NULL,
    `HIGH52` DOUBLE NULL,
    `LOW52` DOUBLE NULL,
    `PE` DOUBLE NULL,
    `EPS` DOUBLE NULL,
    `MARKET_CAP` VARCHAR(255) NULL,
    `SHARES` BIGINT NULL,
    `DIVIDEND_YIELD` DOUBLE NULL,
    `DIVIDEND_SHARE` DOUBLE NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`SYMBOL`, `DATE`)
);


INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('rtd', 'tos_historical_prices', 'SELECT SYMBOL FROM rtd.tos_stock_list', NULL, NULL, 'Eastern Standard Time', NULL);

INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`) VALUES ('rtd', 'tos_historical_prices', 'SYMBOL');
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'DATE', '=Date()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'TIME', '=Time()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'DESCRIPTION', '=TOS|DESCRIPTION![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'LAST', '=TOS|LAST![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'CHANGE', '=TOS|NET_CHANGE![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'PERCENT_CHANGE', '=TOS|PERCENT_CHANGE![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'LAST_SIZE', '=TOS|LAST_SIZE![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'LAST_X', '=TOS|LX![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'MARK', '=TOS|MARK![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'MARK_CHANGE', '=TOS|MARK_CHANGE![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'MARK_PERCENT_CHANGE', '=TOS|MARK_PERCENT_CHANGE![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'BID', '=TOS|BID![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'ASK', '=TOS|ASK![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'BID_SIZE', '=TOS|BID_SIZE![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'ASK_SIZE', '=TOS|ASK_SIZE![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'BID_ASK_SIZE', '=TOS|BA_SIZE![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'BID_X', '=TOS|BX![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'ASK_X', '=TOS|AX![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'STRENGTH_METER', '=TOS|STRENGTH_METER![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'OPEN', '=TOS|OPEN![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'HIGH', '=TOS|HIGH![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'LOW', '=TOS|LOW![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'CLOSE', '=TOS|CLOSE![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'VOLUME', '=TOS|VOLUME![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'OPEN_INT', '=TOS|OPEN_INT![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'IMPLIED_VOL', '=TOS|IMPL_VOL![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'VOL_INDEX', '=TOS|VOL_INDEX![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'FRONT_VOL', '=TOS|FRONT_VOL![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'BACK_VOL', '=TOS|BACK_VOL![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'WEIGHTED_BACK_VOL', '=TOS|WEIGHTED_BACK_VOL![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'VOL_DIFF', '=TOS|VOL_DIFF![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'PUT_CALL_RATIO', '=TOS|PUT_CALL_RATIO![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'CALL_VOLUME_INDEX', '=TOS|CALL_VOLUME_INDEX![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'PUT_VOLUME_INDEX', '=TOS|PUT_VOLUME_INDEX![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'OPTION_VOLUME_INDEX', '=TOS|OPTION_VOLUME_INDEX![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'FRONT_EXPECTED_MOVE', '=TOS|FRONT_EX_MOVE![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'BACK_EXPECTED_MOVE', '=TOS|BACK_EX_MOVE![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'EXPECTED_MOVE_DIFF', '=TOS|EX_MOVE_DIFF![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'BETA', '=TOS|BETA![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'HIGH52', '=TOS|''52HIGH''![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'LOW52', '=TOS|''52LOW''![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'PE', '=TOS|PE![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'EPS', '=TOS|EPS![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'MARKET_CAP', '=TOS|MARKET_CAP![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'SHARES', '=TOS|SHARES![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'DIVIDEND_YIELD', '=TOS|YIELD![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_historical_prices', 'DIVIDEND_SHARE', '=TOS|DIV![SYMBOL]', NULL);

CREATE TABLE IF NOT EXISTS `rtd`.`tos_last_option_data` (
    `CODE` VARCHAR(50) NOT NULL,
    `DATETIME` DATETIME NULL,
    `DATE` DATE NULL,
    `TIME` TIME NULL,
    `DESCRIPTION` VARCHAR(255) NULL,
    `LAST` DOUBLE NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `LAST_SIZE` SMALLINT NULL,
    `LAST_X` CHAR(1) NULL,
    `MARK` DOUBLE NULL,
    `MARK_CHANGE` DOUBLE NULL,
    `MARK_PERCENT_CHANGE` DOUBLE NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `BID_SIZE` SMALLINT NULL,
    `ASK_SIZE` SMALLINT NULL,
    `BID_ASK_SIZE` VARCHAR(50) NULL,
    `BID_X` CHAR(1) NULL,
    `ASK_X` CHAR(1) NULL,
    `OPEN` DOUBLE NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `CLOSE` DOUBLE NULL,
    `VOLUME` INTEGER NULL,
    `OPEN_INT` INTEGER NULL,
    `IMPLIED_VOL` DOUBLE NULL,
    `DELTA` DOUBLE NULL,
    `GAMMA` DOUBLE NULL,
    `THETA` DOUBLE NULL,
    `VEGA` DOUBLE NULL,
    `RHO` DOUBLE NULL,
    `EXTRINSIC` DOUBLE NULL,
    `INTRINSIC` DOUBLE NULL,
    `PROBABILITY_ITM` DOUBLE NULL,
    `PROBABILITY_OTM` DOUBLE NULL,
    `PROBABILITY_TOUCH` DOUBLE NULL,
    `COVERED_RETURN` DOUBLE NULL,
    `MAX_COVERED_RETURN` DOUBLE NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`CODE`)
);


INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('rtd', 'tos_last_option_data', 'SELECT CODE FROM rtd.tos_option_list', NULL, NULL, 'Eastern Standard Time', NULL);

INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`) VALUES ('rtd', 'tos_last_option_data', 'CODE');
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'DATETIME', '=DateTime()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'DATE', '=Date()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'TIME', '=Time()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'DESCRIPTION', '=TOS|DESCRIPTION!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'LAST', '=TOS|LAST!''[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'CHANGE', '=TOS|NET_CHANGE!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'PERCENT_CHANGE', '=TOS|PERCENT_CHANGE!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'LAST_SIZE', '=TOS|LAST_SIZE!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'LAST_X', '=TOS|LX!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'MARK', '=TOS|MARK!''[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'MARK_CHANGE', '=TOS|MARK_CHANGE!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'MARK_PERCENT_CHANGE', '=TOS|MARK_PERCENT_CHANGE!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'BID', '=TOS|BID!''[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'ASK', '=TOS|ASK!''[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'BID_SIZE', '=TOS|BID_SIZE!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'ASK_SIZE', '=TOS|ASK_SIZE!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'BID_ASK_SIZE', '=TOS|BA_SIZE!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'BID_X', '=TOS|BX!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'ASK_X', '=TOS|AX!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'OPEN', '=TOS|OPEN!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'HIGH', '=TOS|HIGH!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'LOW', '=TOS|LOW!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'CLOSE', '=TOS|Close!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'VOLUME', '=TOS|VOLUME!''[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'OPEN_INT', '=TOS|OPEN_INT!''[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'IMPLIED_VOL', '=TOS|IMPL_VOL!''[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'DELTA', '=TOS|DELTA!''[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'GAMMA', '=TOS|GAMMA!''[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'THETA', '=TOS|THETA!''[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'VEGA', '=TOS|VEGA!''[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'RHO', '=TOS|RHO!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'EXTRINSIC', '=TOS|EXTRINSIC!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'INTRINSIC', '=TOS|INTRINSIC!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'PROBABILITY_ITM', '=TOS|PROB_OF_EXPIRING!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'PROBABILITY_OTM', '=TOS|PROB_OTM!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'PROBABILITY_TOUCH', '=TOS|PROB_OF_TOUCHING!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'COVERED_RETURN', '=TOS|COVERED_RETURN!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_option_data', 'MAX_COVERED_RETURN', '=TOS|MAX_COVERED_RETURN!''[CODE]''', 1);

CREATE TABLE IF NOT EXISTS `rtd`.`tos_last_stock_quotes` (
    `SYMBOL` VARCHAR(50) NOT NULL,
    `DATETIME` DATETIME NOT NULL,
    `DATE` DATE NULL,
    `TIME` TIME NULL,
    `DESCRIPTION` VARCHAR(255) NULL,
    `LAST` DOUBLE NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `LAST_SIZE` INTEGER NULL,
    `LAST_X` CHAR(1) NULL,
    `MARK` DOUBLE NULL,
    `MARK_CHANGE` DOUBLE NULL,
    `MARK_PERCENT_CHANGE` DOUBLE NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `BID_SIZE` INTEGER NULL,
    `ASK_SIZE` INTEGER NULL,
    `BID_ASK_SIZE` VARCHAR(255) NULL,
    `BID_X` CHAR(1) NULL,
    `ASK_X` CHAR(1) NULL,
    `STRENGTH_METER` VARCHAR(255) NULL,
    `OPEN` DOUBLE NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `CLOSE` DOUBLE NULL,
    `VOLUME` BIGINT NULL,
    `OPEN_INT` INTEGER NULL,
    `IMPLIED_VOL` DOUBLE NULL,
    `VOL_INDEX` DOUBLE NULL,
    `FRONT_VOL` DOUBLE NULL,
    `BACK_VOL` DOUBLE NULL,
    `WEIGHTED_BACK_VOL` DOUBLE NULL,
    `VOL_DIFF` DOUBLE NULL,
    `PUT_CALL_RATIO` DOUBLE NULL,
    `CALL_VOLUME_INDEX` DOUBLE NULL,
    `PUT_VOLUME_INDEX` DOUBLE NULL,
    `OPTION_VOLUME_INDEX` DOUBLE NULL,
    `FRONT_EXPECTED_MOVE` DOUBLE NULL,
    `BACK_EXPECTED_MOVE` DOUBLE NULL,
    `EXPECTED_MOVE_DIFF` DOUBLE NULL,
    `BETA` DOUBLE NULL,
    `HIGH52` DOUBLE NULL,
    `LOW52` DOUBLE NULL,
    `PE` DOUBLE NULL,
    `EPS` DOUBLE NULL,
    `MARKET_CAP` VARCHAR(255) NULL,
    `SHARES` BIGINT NULL,
    `DIVIDEND_YIELD` DOUBLE NULL,
    `DIVIDEND_SHARE` DOUBLE NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`SYMBOL`)
);


INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('rtd', 'tos_last_stock_quotes', 'SELECT SYMBOL FROM rtd.tos_stock_list', NULL, NULL, 'Eastern Standard Time', NULL);

INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`) VALUES ('rtd', 'tos_last_stock_quotes', 'SYMBOL');
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'DATETIME', '=DateTime()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'DATE', '=Date()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'TIME', '=Time()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'DESCRIPTION', '=TOS|DESCRIPTION![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'LAST', '=TOS|LAST![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'CHANGE', '=TOS|NET_CHANGE![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'PERCENT_CHANGE', '=TOS|PERCENT_CHANGE![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'LAST_SIZE', '=TOS|LAST_SIZE![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'LAST_X', '=TOS|LX![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'MARK', '=TOS|MARK![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'MARK_CHANGE', '=TOS|MARK_CHANGE![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'MARK_PERCENT_CHANGE', '=TOS|MARK_PERCENT_CHANGE![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'BID', '=TOS|BID![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'ASK', '=TOS|ASK![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'BID_SIZE', '=TOS|BID_SIZE![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'ASK_SIZE', '=TOS|ASK_SIZE![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'BID_ASK_SIZE', '=TOS|BA_SIZE![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'BID_X', '=TOS|BX![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'ASK_X', '=TOS|AX![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'STRENGTH_METER', '=TOS|STRENGTH_METER![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'OPEN', '=TOS|OPEN![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'HIGH', '=TOS|HIGH![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'LOW', '=TOS|LOW![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'CLOSE', '=TOS|CLOSE![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'VOLUME', '=TOS|VOLUME![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'OPEN_INT', '=TOS|OPEN_INT![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'IMPLIED_VOL', '=TOS|IMPL_VOL![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'VOL_INDEX', '=TOS|VOL_INDEX![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'FRONT_VOL', '=TOS|FRONT_VOL![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'BACK_VOL', '=TOS|BACK_VOL![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'WEIGHTED_BACK_VOL', '=TOS|WEIGHTED_BACK_VOL![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'VOL_DIFF', '=TOS|VOL_DIFF![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'PUT_CALL_RATIO', '=TOS|PUT_CALL_RATIO![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'CALL_VOLUME_INDEX', '=TOS|CALL_VOLUME_INDEX![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'PUT_VOLUME_INDEX', '=TOS|PUT_VOLUME_INDEX![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'OPTION_VOLUME_INDEX', '=TOS|OPTION_VOLUME_INDEX![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'FRONT_EXPECTED_MOVE', '=TOS|FRONT_EX_MOVE![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'BACK_EXPECTED_MOVE', '=TOS|BACK_EX_MOVE![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'EXPECTED_MOVE_DIFF', '=TOS|EX_MOVE_DIFF![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'BETA', '=TOS|BETA![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'HIGH52', '=TOS|''52HIGH''![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'LOW52', '=TOS|''52LOW''![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'PE', '=TOS|PE![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'EPS', '=TOS|EPS![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'MARKET_CAP', '=TOS|MARKET_CAP![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'SHARES', '=TOS|SHARES![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'DIVIDEND_YIELD', '=TOS|YIELD![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_last_stock_quotes', 'DIVIDEND_SHARE', '=TOS|DIV![SYMBOL]', NULL);

CREATE TABLE IF NOT EXISTS `rtd`.`tos_option_data_s` (
    `CODE` VARCHAR(50) NOT NULL,
    `DATETIME` DATETIME NOT NULL,
    `DATE` DATE NOT NULL,
    `TIME` TIME NOT NULL,
    `DESCRIPTION` VARCHAR(255) NULL,
    `LAST` DOUBLE NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `LAST_SIZE` SMALLINT NULL,
    `LAST_X` CHAR(1) NULL,
    `MARK` DOUBLE NULL,
    `MARK_CHANGE` DOUBLE NULL,
    `MARK_PERCENT_CHANGE` DOUBLE NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `BID_SIZE` SMALLINT NULL,
    `ASK_SIZE` SMALLINT NULL,
    `BID_ASK_SIZE` VARCHAR(50) NULL,
    `BID_X` CHAR(1) NULL,
    `ASK_X` CHAR(1) NULL,
    `OPEN` DOUBLE NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `CLOSE` DOUBLE NULL,
    `VOLUME` INTEGER NULL,
    `OPEN_INT` INTEGER NULL,
    `IMPLIED_VOL` DOUBLE NULL,
    `DELTA` DOUBLE NULL,
    `GAMMA` DOUBLE NULL,
    `THETA` DOUBLE NULL,
    `VEGA` DOUBLE NULL,
    `RHO` DOUBLE NULL,
    `EXTRINSIC` DOUBLE NULL,
    `INTRINSIC` DOUBLE NULL,
    `PROBABILITY_ITM` DOUBLE NULL,
    `PROBABILITY_OTM` DOUBLE NULL,
    `PROBABILITY_TOUCH` DOUBLE NULL,
    `COVERED_RETURN` DOUBLE NULL,
    `MAX_COVERED_RETURN` DOUBLE NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`CODE`, `DATE`, `TIME`)
);


INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('rtd', 'tos_option_data_s', 'SELECT CODE FROM rtd.tos_option_list', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`) VALUES ('rtd', 'tos_option_data_s', 'CODE');
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'DATETIME', '=DateTime()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'DATE', '=Date()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'TIME', '=Time0()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'DESCRIPTION', '=TOS|DESCRIPTION!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'LAST', '=TOS|LAST!''[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'CHANGE', '=TOS|NET_CHANGE!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'PERCENT_CHANGE', '=TOS|PERCENT_CHANGE!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'LAST_SIZE', '=TOS|LAST_SIZE!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'LAST_X', '=TOS|LX!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'MARK', '=TOS|MARK!''[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'MARK_CHANGE', '=TOS|MARK_CHANGE!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'MARK_PERCENT_CHANGE', '=TOS|MARK_PERCENT_CHANGE!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'BID', '=TOS|BID!''[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'ASK', '=TOS|ASK!''[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'BID_SIZE', '=TOS|BID_SIZE!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'ASK_SIZE', '=TOS|ASK_SIZE!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'BID_ASK_SIZE', '=TOS|BA_SIZE!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'BID_X', '=TOS|BX!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'ASK_X', '=TOS|AX!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'OPEN', '=TOS|OPEN!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'HIGH', '=TOS|HIGH!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'LOW', '=TOS|LOW!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'CLOSE', '=TOS|Close!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'VOLUME', '=TOS|VOLUME!''[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'OPEN_INT', '=TOS|OPEN_INT!''[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'IMPLIED_VOL', '=TOS|IMPL_VOL!''[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'DELTA', '=TOS|DELTA!''[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'GAMMA', '=TOS|GAMMA!''[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'THETA', '=TOS|THETA!''[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'VEGA', '=TOS|VEGA!''[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'RHO', '=TOS|RHO!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'EXTRINSIC', '=TOS|EXTRINSIC!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'INTRINSIC', '=TOS|INTRINSIC!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'PROBABILITY_ITM', '=TOS|PROB_OF_EXPIRING!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'PROBABILITY_OTM', '=TOS|PROB_OTM!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'PROBABILITY_TOUCH', '=TOS|PROB_OF_TOUCHING!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'COVERED_RETURN', '=TOS|COVERED_RETURN!''[CODE]''', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_option_data_s', 'MAX_COVERED_RETURN', '=TOS|MAX_COVERED_RETURN!''[CODE]''', 1);

CREATE TABLE IF NOT EXISTS `rtd`.`tos_stock_quotes_s` (
    `SYMBOL` VARCHAR(50) NOT NULL,
    `DATETIME` DATETIME NOT NULL,
    `DATE` DATE NOT NULL,
    `TIME` TIME NOT NULL,
    `DESCRIPTION` VARCHAR(255) NULL,
    `LAST` DOUBLE NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `LAST_SIZE` INTEGER NULL,
    `LAST_X` CHAR(1) NULL,
    `MARK` DOUBLE NULL,
    `MARK_CHANGE` DOUBLE NULL,
    `MARK_PERCENT_CHANGE` DOUBLE NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `BID_SIZE` INTEGER NULL,
    `ASK_SIZE` INTEGER NULL,
    `BID_ASK_SIZE` VARCHAR(255) NULL,
    `BID_X` CHAR(1) NULL,
    `ASK_X` CHAR(1) NULL,
    `STRENGTH_METER` VARCHAR(255) NULL,
    `OPEN` DOUBLE NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `CLOSE` DOUBLE NULL,
    `VOLUME` BIGINT NULL,
    `OPEN_INT` INTEGER NULL,
    `IMPLIED_VOL` DOUBLE NULL,
    `VOL_INDEX` DOUBLE NULL,
    `FRONT_VOL` DOUBLE NULL,
    `BACK_VOL` DOUBLE NULL,
    `WEIGHTED_BACK_VOL` DOUBLE NULL,
    `VOL_DIFF` DOUBLE NULL,
    `PUT_CALL_RATIO` DOUBLE NULL,
    `CALL_VOLUME_INDEX` DOUBLE NULL,
    `PUT_VOLUME_INDEX` DOUBLE NULL,
    `OPTION_VOLUME_INDEX` DOUBLE NULL,
    `FRONT_EXPECTED_MOVE` DOUBLE NULL,
    `BACK_EXPECTED_MOVE` DOUBLE NULL,
    `EXPECTED_MOVE_DIFF` DOUBLE NULL,
    `BETA` DOUBLE NULL,
    `HIGH52` DOUBLE NULL,
    `LOW52` DOUBLE NULL,
    `PE` DOUBLE NULL,
    `EPS` DOUBLE NULL,
    `MARKET_CAP` VARCHAR(255) NULL,
    `SHARES` BIGINT NULL,
    `DIVIDEND_YIELD` DOUBLE NULL,
    `DIVIDEND_SHARE` DOUBLE NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`SYMBOL`, `DATE`)
);


INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('rtd', 'tos_stock_quotes_s', 'SELECT SYMBOL FROM rtd.tos_stock_list', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`) VALUES ('rtd', 'tos_stock_quotes_s', 'SYMBOL');
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'DATETIME', '=DateTime()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'DATE', '=Date()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'TIME', '=Time0()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'DESCRIPTION', '=TOS|DESCRIPTION![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'LAST', '=TOS|LAST![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'CHANGE', '=TOS|NET_CHANGE![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'PERCENT_CHANGE', '=TOS|PERCENT_CHANGE![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'LAST_SIZE', '=TOS|LAST_SIZE![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'LAST_X', '=TOS|LX![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'MARK', '=TOS|MARK![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'MARK_CHANGE', '=TOS|MARK_CHANGE![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'MARK_PERCENT_CHANGE', '=TOS|MARK_PERCENT_CHANGE![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'BID', '=TOS|BID![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'ASK', '=TOS|ASK![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'BID_SIZE', '=TOS|BID_SIZE![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'ASK_SIZE', '=TOS|ASK_SIZE![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'BID_ASK_SIZE', '=TOS|BA_SIZE![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'BID_X', '=TOS|BX![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'ASK_X', '=TOS|AX![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'STRENGTH_METER', '=TOS|STRENGTH_METER![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'OPEN', '=TOS|OPEN![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'HIGH', '=TOS|HIGH![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'LOW', '=TOS|LOW![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'CLOSE', '=TOS|CLOSE![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'VOLUME', '=TOS|VOLUME![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'OPEN_INT', '=TOS|OPEN_INT![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'IMPLIED_VOL', '=TOS|IMPL_VOL![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'VOL_INDEX', '=TOS|VOL_INDEX![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'FRONT_VOL', '=TOS|FRONT_VOL![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'BACK_VOL', '=TOS|BACK_VOL![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'WEIGHTED_BACK_VOL', '=TOS|WEIGHTED_BACK_VOL![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'VOL_DIFF', '=TOS|VOL_DIFF![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'PUT_CALL_RATIO', '=TOS|PUT_CALL_RATIO![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'CALL_VOLUME_INDEX', '=TOS|CALL_VOLUME_INDEX![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'PUT_VOLUME_INDEX', '=TOS|PUT_VOLUME_INDEX![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'OPTION_VOLUME_INDEX', '=TOS|OPTION_VOLUME_INDEX![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'FRONT_EXPECTED_MOVE', '=TOS|FRONT_EX_MOVE![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'BACK_EXPECTED_MOVE', '=TOS|BACK_EX_MOVE![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'EXPECTED_MOVE_DIFF', '=TOS|EX_MOVE_DIFF![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'BETA', '=TOS|BETA![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'HIGH52', '=TOS|''52HIGH''![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'LOW52', '=TOS|''52LOW''![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'PE', '=TOS|PE![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'EPS', '=TOS|EPS![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'MARKET_CAP', '=TOS|MARKET_CAP![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'SHARES', '=TOS|SHARES![SYMBOL]', 1);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'DIVIDEND_YIELD', '=TOS|YIELD![SYMBOL]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`, `IS_DISABLED`) VALUES ('rtd', 'tos_stock_quotes_s', 'DIVIDEND_SHARE', '=TOS|DIV![SYMBOL]', NULL);

