CREATE SCHEMA IF NOT EXISTS `rtd`;

CREATE TABLE IF NOT EXISTS `rtd`.`real_time_formulas` (
    `ID` INTEGER NOT NULL AUTO_INCREMENT,
    `TABLE_SCHEMA` VARCHAR(128) NOT NULL,
    `TABLE_NAME` VARCHAR(128) NOT NULL,
    `COLUMN_NAME` VARCHAR(128) NOT NULL,
    `RTD_FORMULA` VARCHAR(255) NULL,
    `IS_DISABLED` TINYINT NULL,
  PRIMARY KEY (`ID`)
);

ALTER TABLE `rtd`.`real_time_formulas`
    ADD UNIQUE INDEX `ix_real_time_formulas_schema_name_column_name`
    USING BTREE (
       `TABLE_SCHEMA`,
       `TABLE_NAME`,
       `COLUMN_NAME`
    );


CREATE TABLE IF NOT EXISTS `rtd`.`real_time_tables` (
    `ID` INTEGER NOT NULL AUTO_INCREMENT,
    `TABLE_SCHEMA` VARCHAR(128) NOT NULL,
    `TABLE_NAME` VARCHAR(128) NOT NULL,
    `LOAD_CODE` VARCHAR(2000) NULL,
    `IS_HISTORY` TINYINT NULL,
    `IS_DISABLED` TINYINT NULL,
    `TIME_ZONE` VARCHAR(50) NULL,
    `RTD_INSTANCE_NAME` VARCHAR(50) NULL,
  PRIMARY KEY (`ID`)
);

ALTER TABLE `rtd`.`real_time_tables`
    ADD UNIQUE INDEX `ix_realtimetables_schema_name`
    USING BTREE (
       `TABLE_SCHEMA`,
       `TABLE_NAME`
    );
    
CREATE TABLE IF NOT EXISTS `rtd`.`vfx_stock_list` (
    `CODE` VARCHAR(50) NOT NULL,
  PRIMARY KEY (`CODE`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`vfx_historical_prices` (
    `SYMBOL` VARCHAR(50) NOT NULL,
    `DATE` DATE NOT NULL,
    `TIME` TIME NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `OPEN` DOUBLE NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `CLOSE` DOUBLE NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`SYMBOL`, `DATE`)
);


INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('rtd', 'vfx_historical_prices', 'SELECT CODE FROM rtd.vfx_stock_list', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_historical_prices', 'CODE', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_historical_prices', 'SYMBOL', '=VFX|Name![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_historical_prices', 'DATE', '=Date()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_historical_prices', 'TIME', '=VFX|Time![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_historical_prices', 'CHANGE', '=VFX|NetChange![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_historical_prices', 'PERCENT_CHANGE', '=VFX|PercentChange![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_historical_prices', 'BID', '=VFX|Bid![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_historical_prices', 'ASK', '=VFX|Ask![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_historical_prices', 'OPEN', '=VFX|OpenPrice![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_historical_prices', 'HIGH', '=VFX|High![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_historical_prices', 'LOW', '=VFX|Low![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_historical_prices', 'CLOSE', '=VFX|ClosePrice![CODE]', NULL);

CREATE TABLE IF NOT EXISTS `rtd`.`vfx_last_stock_quotes` (
    `SYMBOL` VARCHAR(50) NOT NULL,
    `DATE` DATE NULL,
    `TIME` TIME NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `OPEN` DOUBLE NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `CLOSE` DOUBLE NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`SYMBOL`)
);


INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('rtd', 'vfx_last_stock_quotes', 'SELECT CODE FROM rtd.vfx_stock_list', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_last_stock_quotes', 'CODE', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_last_stock_quotes', 'SYMBOL', '=VFX|Name![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_last_stock_quotes', 'DATE', '=Date()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_last_stock_quotes', 'TIME', '=VFX|Time![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_last_stock_quotes', 'CHANGE', '=VFX|NetChange![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_last_stock_quotes', 'PERCENT_CHANGE', '=VFX|PercentChange![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_last_stock_quotes', 'BID', '=VFX|Bid![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_last_stock_quotes', 'ASK', '=VFX|Ask![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_last_stock_quotes', 'OPEN', '=VFX|OpenPrice![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_last_stock_quotes', 'HIGH', '=VFX|High![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_last_stock_quotes', 'LOW', '=VFX|Low![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_last_stock_quotes', 'CLOSE', '=VFX|ClosePrice![CODE]', NULL);

CREATE TABLE IF NOT EXISTS `rtd`.`vfx_stock_quotes_ticks` (
    `ID` INTEGER NOT NULL AUTO_INCREMENT,
    `SYMBOL` VARCHAR(50) NOT NULL,
    `DATE` DATE NULL,
    `TIME` TIME NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `OPEN` DOUBLE NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `CLOSE` DOUBLE NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
  PRIMARY KEY (`ID`)
);


INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('rtd', 'vfx_stock_quotes_ticks', 'SELECT CODE FROM rtd.vfx_stock_list', 1, 1, 'Eastern Standard Time', NULL);

INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_stock_quotes_ticks', 'ID', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_stock_quotes_ticks', 'CODE', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_stock_quotes_ticks', 'SYMBOL', '=VFX|Name![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_stock_quotes_ticks', 'DATE', '=Date()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_stock_quotes_ticks', 'TIME', '=VFX|Time![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_stock_quotes_ticks', 'CHANGE', '=VFX|NetChange![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_stock_quotes_ticks', 'PERCENT_CHANGE', '=VFX|PercentChange![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_stock_quotes_ticks', 'BID', '=VFX|Bid![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_stock_quotes_ticks', 'ASK', '=VFX|Ask![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_stock_quotes_ticks', 'OPEN', '=VFX|OpenPrice![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_stock_quotes_ticks', 'HIGH', '=VFX|High![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_stock_quotes_ticks', 'LOW', '=VFX|Low![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_stock_quotes_ticks', 'CLOSE', '=VFX|ClosePrice![CODE]', NULL);

CREATE TABLE IF NOT EXISTS `rtd`.`vfx_stock_quotes_time` (
    `SYMBOL` VARCHAR(50) NOT NULL,
    `DATE` DATE NOT NULL,
    `TIME` TIME NOT NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `OPEN` DOUBLE NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `CLOSE` DOUBLE NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY
(
    `SYMBOL`,
    `DATE`,
    `TIME`
)
);


INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('rtd', 'vfx_stock_quotes_time', 'SELECT CODE FROM rtd.vfx_stock_list', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_stock_quotes_time', 'CODE', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_stock_quotes_time', 'SYMBOL', '=VFX|Name![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_stock_quotes_time', 'DATE', '=Date()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_stock_quotes_time', 'TIME', '=VFX|Time![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_stock_quotes_time', 'CHANGE', '=VFX|NetChange![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_stock_quotes_time', 'PERCENT_CHANGE', '=VFX|PercentChange![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_stock_quotes_time', 'BID', '=VFX|Bid![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_stock_quotes_time', 'ASK', '=VFX|Ask![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_stock_quotes_time', 'OPEN', '=VFX|OpenPrice![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_stock_quotes_time', 'HIGH', '=VFX|High![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_stock_quotes_time', 'LOW', '=VFX|Low![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'vfx_stock_quotes_time', 'CLOSE', '=VFX|ClosePrice![CODE]', NULL);

