CREATE USER RTD
  IDENTIFIED BY "r#td_2014_abc!"
    DEFAULT TABLESPACE USERS
    TEMPORARY TABLESPACE TEMP
    PROFILE "DEFAULT"
    ACCOUNT UNLOCK
    QUOTA UNLIMITED ON USERS;

GRANT CONNECT TO RTD;

CREATE TABLE "RTD"."REAL_TIME_FORMULAS" (
    "ID" NUMBER NOT NULL,
    "TABLE_SCHEMA" VARCHAR2(128) NOT NULL,
    "TABLE_NAME" VARCHAR2(128) NOT NULL,
    "COLUMN_NAME" VARCHAR2(128) NOT NULL,
    "RTD_FORMULA" VARCHAR2(255) NULL,
    "IS_DISABLED" NUMBER(1) NULL,
  CONSTRAINT "PK_REAL_TIME_FORMULAS"
    PRIMARY KEY ("ID"),
  CONSTRAINT "IX_REAL_TIME_FORMULAS_COLUMN"
    UNIQUE ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME")
);

CREATE SEQUENCE "RTD"."SQ_REAL_TIME_FORMULAS_ID"
  INCREMENT BY 1
  START WITH 1
  MAXVALUE 1E28
  MINVALUE 1
  NOCYCLE
  CACHE 20
  NOORDER;

CREATE TRIGGER "RTD"."TRG_REAL_TIME_FORMULAS_ID"
  BEFORE INSERT OR UPDATE
  ON "RTD"."REAL_TIME_FORMULAS"
REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW
BEGIN
  IF :new.ID IS NULL THEN
    SELECT SQ_REAL_TIME_FORMULAS_ID.NEXTVAL INTO :new.ID FROM dual;
  END IF;
END;
/

CREATE TABLE "RTD"."REAL_TIME_TABLES" (
    "ID" NUMBER NOT NULL,
    "TABLE_SCHEMA" VARCHAR2(128) NOT NULL,
    "TABLE_NAME" VARCHAR2(128) NOT NULL,
    "LOAD_CODE" VARCHAR2(2000) NULL,
    "IS_HISTORY" NUMBER(1) NULL,
    "IS_DISABLED" NUMBER(1) NULL,
    "TIME_ZONE" VARCHAR2(50) NULL,
    "RTD_INSTANCE_NAME" VARCHAR2(50) NULL,
  CONSTRAINT "PK_REAL_TIME_TABLES"
    PRIMARY KEY ("ID"),
  CONSTRAINT "IX_REAL_TIME_TABLES_TABLE"
    UNIQUE ("TABLE_SCHEMA", "TABLE_NAME")
);

CREATE SEQUENCE "RTD"."SQ_REAL_TIME_TABLES_ID"
  INCREMENT BY 1
  START WITH 1
  MAXVALUE 1E28
  MINVALUE 1
  NOCYCLE
  CACHE 20
  NOORDER;

CREATE TRIGGER "RTD"."TRG_REAL_TIME_TABLES_ID"
  BEFORE INSERT OR UPDATE
  ON "RTD"."REAL_TIME_TABLES"
REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW
BEGIN
  IF :new.ID IS NULL THEN
    SELECT SQ_REAL_TIME_TABLES_ID.NEXTVAL INTO :new.ID FROM dual;
  END IF;
END;
/

CREATE TABLE "RTD"."TWS_STOCK_LIST" (
    "TICK_ID" NUMBER NOT NULL,
    "CODE" VARCHAR2(50) NOT NULL,
  CONSTRAINT "PK_TWS_STOCK_LIST"
    PRIMARY KEY ("TICK_ID"),
  CONSTRAINT "IX_TWS_STOCK_LIST_CODE"
    UNIQUE ("CODE")
);

CREATE SEQUENCE "RTD"."SQ_TWS_STOCK_LIST_ID"
  INCREMENT BY 1
  START WITH 1
  MAXVALUE 1E28
  MINVALUE 1
  NOCYCLE
  CACHE 20
  NOORDER;

CREATE TRIGGER "RTD"."TRG_TWS_STOCK_LIST_ID"
  BEFORE INSERT OR UPDATE
  ON "RTD"."TWS_STOCK_LIST"
REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW
BEGIN
  IF :new.TICK_ID IS NULL THEN
    SELECT SQ_TWS_STOCK_LIST_ID.NEXTVAL INTO :new.TICK_ID FROM dual;
  END IF;
END;
/

CREATE TABLE "RTD"."TWS_HISTORICAL_OPTION_DATA" (
    "CODE" VARCHAR2(255) NOT NULL,
    "DATE" DATE NOT NULL,
    "TIME" TIMESTAMP(3) NULL,
    "LAST" BINARY_DOUBLE NULL,
    "LAST_SIZE" NUMBER NULL,
    "BID" BINARY_DOUBLE NULL,
    "ASK" BINARY_DOUBLE NULL,
    "BID_SIZE" NUMBER NULL,
    "ASK_SIZE" NUMBER NULL,
    "HIGH" BINARY_DOUBLE NULL,
    "LOW" BINARY_DOUBLE NULL,
    "CLOSE" BINARY_DOUBLE NULL,
    "VOLUME" NUMBER NULL,
    "UNDERLYING_PRICE" BINARY_DOUBLE NULL,
    "MODEL_PRICE" BINARY_DOUBLE NULL,
    "IMPLIED_VOL" BINARY_DOUBLE NULL,
    "BID_IMPLIED_VOL" BINARY_DOUBLE NULL,
    "ASK_IMPLIED_VOL" BINARY_DOUBLE NULL,
    "LAST_IMPLIED_VOL" BINARY_DOUBLE NULL,
    "BID_DELTA" BINARY_DOUBLE NULL,
    "ASK_DELTA" BINARY_DOUBLE NULL,
    "LAST_DELTA" BINARY_DOUBLE NULL,
    "DELTA" BINARY_DOUBLE NULL,
    "GAMMA" BINARY_DOUBLE NULL,
    "THETA" BINARY_DOUBLE NULL,
    "VEGA" BINARY_DOUBLE NULL,
    "PV_DIVIDEND" BINARY_DOUBLE NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
  CONSTRAINT "PK_TWS_HISTORICAL_OPTION_DATA"
    PRIMARY KEY ("CODE", "DATE")
);


INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'TWS_HISTORICAL_OPTION_DATA', 'SELECT TICK_ID, CODE FROM RTD.TWS_STOCK_LIST WHERE CODE LIKE ''%_OPT_20%''', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_OPTION_DATA', 'TICK_ID', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_OPTION_DATA', 'CODE', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_OPTION_DATA', 'REQ', '=S|tik!''id[TICK_ID]?req?[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_OPTION_DATA', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_OPTION_DATA', 'TIME', '=Time()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_OPTION_DATA', 'LAST', '=S|tik!id[TICK_ID]?last', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_OPTION_DATA', 'LAST_SIZE', '=S|tik!id[TICK_ID]?lastSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_OPTION_DATA', 'BID', '=S|tik!id[TICK_ID]?bid', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_OPTION_DATA', 'ASK', '=S|tik!id[TICK_ID]?ask', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_OPTION_DATA', 'BID_SIZE', '=S|tik!id[TICK_ID]?bidSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_OPTION_DATA', 'ASK_SIZE', '=S|tik!id[TICK_ID]?askSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_OPTION_DATA', 'HIGH', '=S|tik!id[TICK_ID]?high', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_OPTION_DATA', 'LOW', '=S|tik!id[TICK_ID]?low', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_OPTION_DATA', 'CLOSE', '=S|tik!id[TICK_ID]?close', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_OPTION_DATA', 'VOLUME', '=S|tik!id[TICK_ID]?volume', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_OPTION_DATA', 'UNDERLYING_PRICE', '=S|tik!id[TICK_ID]?modelUndPrice', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_OPTION_DATA', 'MODEL_PRICE', '=S|tik!id[TICK_ID]?modelPrice', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_OPTION_DATA', 'IMPLIED_VOL', '=S|tik!id[TICK_ID]?modelVolatility', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_OPTION_DATA', 'BID_IMPLIED_VOL', '=S|tik!id[TICK_ID]?bidImpliedVol', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_OPTION_DATA', 'ASK_IMPLIED_VOL', '=S|tik!id[TICK_ID]?askImpliedVol', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_OPTION_DATA', 'LAST_IMPLIED_VOL', '=S|tik!id[TICK_ID]?lastImpliedVol', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_OPTION_DATA', 'BID_DELTA', '=S|tik!id[TICK_ID]?bidDelta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_OPTION_DATA', 'ASK_DELTA', '=S|tik!id[TICK_ID]?askDelta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_OPTION_DATA', 'LAST_DELTA', '=S|tik!id[TICK_ID]?lastDelta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_OPTION_DATA', 'DELTA', '=S|tik!id[TICK_ID]?modelDelta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_OPTION_DATA', 'GAMMA', '=S|tik!id[TICK_ID]?modelGamma', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_OPTION_DATA', 'THETA', '=S|tik!id[TICK_ID]?modelTheta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_OPTION_DATA', 'VEGA', '=S|tik!id[TICK_ID]?modelVega', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_OPTION_DATA', 'PV_DIVIDEND', '=S|tik!id[TICK_ID]?pvDividend', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_OPTION_DATA', 'LAST_UPDATE_TIMESTAMP', '=TimeStamp()', NULL);

CREATE TABLE "RTD"."TWS_HISTORICAL_PRICES" (
    "SYMBOL" VARCHAR2(50) NOT NULL,
    "DATE" DATE NOT NULL,
    "TIME" TIMESTAMP(3) NULL,
    "LAST" BINARY_DOUBLE NULL,
    "LAST_SIZE" NUMBER NULL,
    "BID" BINARY_DOUBLE NULL,
    "ASK" BINARY_DOUBLE NULL,
    "BID_SIZE" NUMBER NULL,
    "ASK_SIZE" NUMBER NULL,
    "HIGH" BINARY_DOUBLE NULL,
    "LOW" BINARY_DOUBLE NULL,
    "CLOSE" BINARY_DOUBLE NULL,
    "VOLUME" NUMBER NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
  CONSTRAINT "PK_TWS_HISTORICAL_PRICES"
    PRIMARY KEY ("SYMBOL", "DATE")
);


INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'TWS_HISTORICAL_PRICES', 'SELECT TICK_ID, CODE AS SYMBOL FROM RTD.TWS_STOCK_LIST WHERE CODE NOT LIKE ''%_OPT_20%''', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_PRICES', 'ID', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_PRICES', 'TICK_ID', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_PRICES', 'SYMBOL', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_PRICES', 'REQ', '=S|tik!''id[TICK_ID]?req?[SYMBOL]_STK_SMART_USD_~''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_PRICES', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_PRICES', 'TIME', '=Time()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_PRICES', 'LAST', '=S|tik!id[TICK_ID]?last', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_PRICES', 'LAST_SIZE', '=S|tik!id[TICK_ID]?lastSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_PRICES', 'BID', '=S|tik!id[TICK_ID]?bid', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_PRICES', 'ASK', '=S|tik!id[TICK_ID]?ask', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_PRICES', 'BID_SIZE', '=S|tik!id[TICK_ID]?bidSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_PRICES', 'ASK_SIZE', '=S|tik!id[TICK_ID]?askSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_PRICES', 'HIGH', '=S|tik!id[TICK_ID]?high', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_PRICES', 'LOW', '=S|tik!id[TICK_ID]?low', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_PRICES', 'CLOSE', '=S|tik!id[TICK_ID]?close', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_PRICES', 'VOLUME', '=S|tik!id[TICK_ID]?volume', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_HISTORICAL_PRICES', 'LAST_UPDATE_TIMESTAMP', '=TimeStamp()', NULL);

CREATE TABLE "RTD"."TWS_LAST_OPTION_DATA" (
    "CODE" VARCHAR2(255) NOT NULL,
    "DATETIME" TIMESTAMP(3) NULL,
    "DATE" DATE NULL,
    "TIME" TIMESTAMP(3) NULL,
    "LAST" BINARY_DOUBLE NULL,
    "LAST_SIZE" NUMBER NULL,
    "BID" BINARY_DOUBLE NULL,
    "ASK" BINARY_DOUBLE NULL,
    "BID_SIZE" NUMBER NULL,
    "ASK_SIZE" NUMBER NULL,
    "HIGH" BINARY_DOUBLE NULL,
    "LOW" BINARY_DOUBLE NULL,
    "CLOSE" BINARY_DOUBLE NULL,
    "VOLUME" NUMBER NULL,
    "UNDERLYING_PRICE" BINARY_DOUBLE NULL,
    "MODEL_PRICE" BINARY_DOUBLE NULL,
    "IMPLIED_VOL" BINARY_DOUBLE NULL,
    "BID_IMPLIED_VOL" BINARY_DOUBLE NULL,
    "ASK_IMPLIED_VOL" BINARY_DOUBLE NULL,
    "LAST_IMPLIED_VOL" BINARY_DOUBLE NULL,
    "BID_DELTA" BINARY_DOUBLE NULL,
    "ASK_DELTA" BINARY_DOUBLE NULL,
    "LAST_DELTA" BINARY_DOUBLE NULL,
    "DELTA" BINARY_DOUBLE NULL,
    "GAMMA" BINARY_DOUBLE NULL,
    "THETA" BINARY_DOUBLE NULL,
    "VEGA" BINARY_DOUBLE NULL,
    "PV_DIVIDEND" BINARY_DOUBLE NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
  CONSTRAINT "PK_TWS_LAST_OPTION_DATA"
    PRIMARY KEY ("CODE")
);


INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'TWS_LAST_OPTION_DATA', 'SELECT TICK_ID, CODE FROM RTD.TWS_STOCK_LIST WHERE CODE LIKE ''%_OPT_20%''', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_OPTION_DATA', 'TICK_ID', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_OPTION_DATA', 'CODE', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_OPTION_DATA', 'REQ', '=S|tik!''id[TICK_ID]?req?[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_OPTION_DATA', 'DATETIME', '=DateTime()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_OPTION_DATA', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_OPTION_DATA', 'TIME', '=Time()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_OPTION_DATA', 'LAST', '=S|tik!id[TICK_ID]?last', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_OPTION_DATA', 'LAST_SIZE', '=S|tik!id[TICK_ID]?lastSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_OPTION_DATA', 'BID', '=S|tik!id[TICK_ID]?bid', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_OPTION_DATA', 'ASK', '=S|tik!id[TICK_ID]?ask', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_OPTION_DATA', 'BID_SIZE', '=S|tik!id[TICK_ID]?bidSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_OPTION_DATA', 'ASK_SIZE', '=S|tik!id[TICK_ID]?askSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_OPTION_DATA', 'HIGH', '=S|tik!id[TICK_ID]?high', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_OPTION_DATA', 'LOW', '=S|tik!id[TICK_ID]?low', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_OPTION_DATA', 'CLOSE', '=S|tik!id[TICK_ID]?close', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_OPTION_DATA', 'VOLUME', '=S|tik!id[TICK_ID]?volume', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_OPTION_DATA', 'UNDERLYING_PRICE', '=S|tik!id[TICK_ID]?modelUndPrice', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_OPTION_DATA', 'MODEL_PRICE', '=S|tik!id[TICK_ID]?modelPrice', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_OPTION_DATA', 'IMPLIED_VOL', '=S|tik!id[TICK_ID]?modelVolatility', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_OPTION_DATA', 'BID_IMPLIED_VOL', '=S|tik!id[TICK_ID]?bidImpliedVol', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_OPTION_DATA', 'ASK_IMPLIED_VOL', '=S|tik!id[TICK_ID]?askImpliedVol', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_OPTION_DATA', 'LAST_IMPLIED_VOL', '=S|tik!id[TICK_ID]?lastImpliedVol', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_OPTION_DATA', 'BID_DELTA', '=S|tik!id[TICK_ID]?bidDelta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_OPTION_DATA', 'ASK_DELTA', '=S|tik!id[TICK_ID]?askDelta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_OPTION_DATA', 'LAST_DELTA', '=S|tik!id[TICK_ID]?lastDelta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_OPTION_DATA', 'DELTA', '=S|tik!id[TICK_ID]?modelDelta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_OPTION_DATA', 'GAMMA', '=S|tik!id[TICK_ID]?modelGamma', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_OPTION_DATA', 'THETA', '=S|tik!id[TICK_ID]?modelTheta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_OPTION_DATA', 'VEGA', '=S|tik!id[TICK_ID]?modelVega', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_OPTION_DATA', 'PV_DIVIDEND', '=S|tik!id[TICK_ID]?pvDividend', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_OPTION_DATA', 'LAST_UPDATE_TIMESTAMP', '=TimeStamp()', NULL);

CREATE TABLE "RTD"."TWS_LAST_STOCK_QUOTES" (
    "SYMBOL" VARCHAR2(50) NOT NULL,
    "DATETIME" TIMESTAMP(3) NULL,
    "DATE" DATE NULL,
    "TIME" TIMESTAMP(3) NULL,
    "LAST" BINARY_DOUBLE NULL,
    "LAST_SIZE" NUMBER NULL,
    "BID" BINARY_DOUBLE NULL,
    "ASK" BINARY_DOUBLE NULL,
    "BID_SIZE" NUMBER NULL,
    "ASK_SIZE" NUMBER NULL,
    "HIGH" BINARY_DOUBLE NULL,
    "LOW" BINARY_DOUBLE NULL,
    "CLOSE" BINARY_DOUBLE NULL,
    "VOLUME" NUMBER NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
  CONSTRAINT "PK_TWS_LAST_STOCK_QUOTES"
    PRIMARY KEY ("SYMBOL")
);


INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'TWS_LAST_STOCK_QUOTES', 'SELECT TICK_ID, CODE AS SYMBOL FROM RTD.TWS_STOCK_LIST WHERE CODE NOT LIKE ''%_OPT_20%''', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_STOCK_QUOTES', 'TICK_ID', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_STOCK_QUOTES', 'SYMBOL', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_STOCK_QUOTES', 'REQ', '=S|tik!''id[TICK_ID]?req?[SYMBOL]_STK_SMART_USD_~''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_STOCK_QUOTES', 'DATETIME', '=DateTime()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_STOCK_QUOTES', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_STOCK_QUOTES', 'TIME', '=Time()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_STOCK_QUOTES', 'LAST', '=S|tik!id[TICK_ID]?last', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_STOCK_QUOTES', 'LAST_SIZE', '=S|tik!id[TICK_ID]?lastSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_STOCK_QUOTES', 'BID', '=S|tik!id[TICK_ID]?bid', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_STOCK_QUOTES', 'ASK', '=S|tik!id[TICK_ID]?ask', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_STOCK_QUOTES', 'BID_SIZE', '=S|tik!id[TICK_ID]?bidSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_STOCK_QUOTES', 'ASK_SIZE', '=S|tik!id[TICK_ID]?askSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_STOCK_QUOTES', 'HIGH', '=S|tik!id[TICK_ID]?high', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_STOCK_QUOTES', 'LOW', '=S|tik!id[TICK_ID]?low', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_STOCK_QUOTES', 'CLOSE', '=S|tik!id[TICK_ID]?close', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_STOCK_QUOTES', 'VOLUME', '=S|tik!id[TICK_ID]?volume', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_LAST_STOCK_QUOTES', 'LAST_UPDATE_TIMESTAMP', '=TimeStamp()', NULL);

CREATE TABLE "RTD"."TWS_OPTION_DATA_TICKS" (
    "ID" NUMBER NOT NULL,
    "CODE" VARCHAR2(255) NULL,
    "DATETIME" TIMESTAMP(3) NULL,
    "DATE" DATE NULL,
    "TIME" TIMESTAMP(3) NULL,
    "LAST" BINARY_DOUBLE NULL,
    "LAST_SIZE" NUMBER NULL,
    "BID" BINARY_DOUBLE NULL,
    "ASK" BINARY_DOUBLE NULL,
    "BID_SIZE" NUMBER NULL,
    "ASK_SIZE" NUMBER NULL,
    "HIGH" BINARY_DOUBLE NULL,
    "LOW" BINARY_DOUBLE NULL,
    "CLOSE" BINARY_DOUBLE NULL,
    "VOLUME" NUMBER NULL,
    "UNDERLYING_PRICE" BINARY_DOUBLE NULL,
    "MODEL_PRICE" BINARY_DOUBLE NULL,
    "IMPLIED_VOL" BINARY_DOUBLE NULL,
    "BID_IMPLIED_VOL" BINARY_DOUBLE NULL,
    "ASK_IMPLIED_VOL" BINARY_DOUBLE NULL,
    "LAST_IMPLIED_VOL" BINARY_DOUBLE NULL,
    "BID_DELTA" BINARY_DOUBLE NULL,
    "ASK_DELTA" BINARY_DOUBLE NULL,
    "LAST_DELTA" BINARY_DOUBLE NULL,
    "DELTA" BINARY_DOUBLE NULL,
    "GAMMA" BINARY_DOUBLE NULL,
    "THETA" BINARY_DOUBLE NULL,
    "VEGA" BINARY_DOUBLE NULL,
    "PV_DIVIDEND" BINARY_DOUBLE NULL,
  CONSTRAINT "PK_TWS_OPTION_DATA_TICKS"
    PRIMARY KEY ("ID")
);

CREATE SEQUENCE "RTD"."SQ_TWS_OPTION_DATA_TICKS_ID"
  INCREMENT BY 1
  START WITH 1
  MAXVALUE 1E28
  MINVALUE 1
  NOCYCLE
  CACHE 20
  NOORDER;

CREATE TRIGGER "RTD"."TRG_TWS_OPTION_DATA_TICKS_ID"
  BEFORE INSERT OR UPDATE
  ON "RTD"."TWS_OPTION_DATA_TICKS"
REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW
BEGIN
  IF :new.ID IS NULL THEN
    SELECT SQ_TWS_OPTION_DATA_TICKS_ID.NEXTVAL INTO :new.ID FROM dual;
  END IF;
END;
/

INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'SELECT TICK_ID, CODE FROM RTD.TWS_STOCK_LIST WHERE CODE LIKE ''%_OPT_20%''', 1, 1, 'Eastern Standard Time', NULL);

INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'ID', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'TICK_ID', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'CODE', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'REQ', '=S|tik!''id[TICK_ID]?req?[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'DATETIME', '=DateTime()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'TIME', '=Time()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'LAST', '=S|tik!id[TICK_ID]?last', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'LAST_SIZE', '=S|tik!id[TICK_ID]?lastSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'BID', '=S|tik!id[TICK_ID]?bid', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'ASK', '=S|tik!id[TICK_ID]?ask', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'BID_SIZE', '=S|tik!id[TICK_ID]?bidSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'ASK_SIZE', '=S|tik!id[TICK_ID]?askSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'HIGH', '=S|tik!id[TICK_ID]?high', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'LOW', '=S|tik!id[TICK_ID]?low', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'CLOSE', '=S|tik!id[TICK_ID]?close', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'VOLUME', '=S|tik!id[TICK_ID]?volume', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'UNDERLYING_PRICE', '=S|tik!id[TICK_ID]?modelUndPrice', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'MODEL_PRICE', '=S|tik!id[TICK_ID]?modelPrice', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'IMPLIED_VOL', '=S|tik!id[TICK_ID]?modelVolatility', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'BID_IMPLIED_VOL', '=S|tik!id[TICK_ID]?bidImpliedVol', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'ASK_IMPLIED_VOL', '=S|tik!id[TICK_ID]?askImpliedVol', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'LAST_IMPLIED_VOL', '=S|tik!id[TICK_ID]?lastImpliedVol', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'BID_DELTA', '=S|tik!id[TICK_ID]?bidDelta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'ASK_DELTA', '=S|tik!id[TICK_ID]?askDelta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'LAST_DELTA', '=S|tik!id[TICK_ID]?lastDelta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'DELTA', '=S|tik!id[TICK_ID]?modelDelta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'GAMMA', '=S|tik!id[TICK_ID]?modelGamma', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'THETA', '=S|tik!id[TICK_ID]?modelTheta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'VEGA', '=S|tik!id[TICK_ID]?modelVega', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'PV_DIVIDEND', '=S|tik!id[TICK_ID]?pvDividend', NULL);

CREATE TABLE "RTD"."TWS_STOCK_QUOTES_TICKS" (
    "ID" NUMBER NOT NULL,
    "SYMBOL" VARCHAR2(50) NULL,
    "DATETIME" TIMESTAMP(3) NULL,
    "DATE" DATE NULL,
    "TIME" TIMESTAMP(3) NULL,
    "LAST" BINARY_DOUBLE NULL,
    "LAST_SIZE" NUMBER NULL,
    "BID" BINARY_DOUBLE NULL,
    "ASK" BINARY_DOUBLE NULL,
    "BID_SIZE" NUMBER NULL,
    "ASK_SIZE" NUMBER NULL,
    "HIGH" BINARY_DOUBLE NULL,
    "LOW" BINARY_DOUBLE NULL,
    "CLOSE" BINARY_DOUBLE NULL,
    "VOLUME" NUMBER NULL,
  CONSTRAINT "PK_TWS_STOCK_QUOTES_TICKS"
    PRIMARY KEY ("ID")
);

CREATE SEQUENCE "RTD"."SQ_TWS_STOCK_QUOTES_TICKS_ID"
  INCREMENT BY 1
  START WITH 1
  MAXVALUE 1E28
  MINVALUE 1
  NOCYCLE
  CACHE 20
  NOORDER;

CREATE TRIGGER "RTD"."TRG_TWS_STOCK_QUOTES_TICKS_ID"
  BEFORE INSERT OR UPDATE
  ON "RTD"."TWS_STOCK_QUOTES_TICKS"
REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW
BEGIN
  IF :new.ID IS NULL THEN
    SELECT SQ_TWS_STOCK_QUOTES_TICKS_ID.NEXTVAL INTO :new.ID FROM dual;
  END IF;
END;
/


INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'SELECT TICK_ID, CODE AS SYMBOL FROM RTD.TWS_STOCK_LIST WHERE CODE NOT LIKE ''%_OPT_20%''', 1, 1, 'Eastern Standard Time', NULL);

INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'ID', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'TICK_ID', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'SYMBOL', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'REQ', '=S|tik!''id[TICK_ID]?req?[SYMBOL]_STK_SMART_USD_~''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'DATETIME', '=DateTime()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'TIME', '=Time()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'LAST', '=S|tik!id[TICK_ID]?last', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'LAST_SIZE', '=S|tik!id[TICK_ID]?lastSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'BID', '=S|tik!id[TICK_ID]?bid', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'ASK', '=S|tik!id[TICK_ID]?ask', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'BID_SIZE', '=S|tik!id[TICK_ID]?bidSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'ASK_SIZE', '=S|tik!id[TICK_ID]?askSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'HIGH', '=S|tik!id[TICK_ID]?high', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'LOW', '=S|tik!id[TICK_ID]?low', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'CLOSE', '=S|tik!id[TICK_ID]?close', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'VOLUME', '=S|tik!id[TICK_ID]?volume', NULL);

