CREATE USER RTD
  IDENTIFIED BY "r#td_2014_abc!"
    DEFAULT TABLESPACE USERS
    TEMPORARY TABLESPACE TEMP
    PROFILE "DEFAULT"
    ACCOUNT UNLOCK
    QUOTA UNLIMITED ON USERS;

GRANT CONNECT TO RTD;

CREATE TABLE "RTD"."REAL_TIME_FORMULAS" (
    "ID" NUMBER NOT NULL,
    "TABLE_SCHEMA" VARCHAR2(128) NOT NULL,
    "TABLE_NAME" VARCHAR2(128) NOT NULL,
    "COLUMN_NAME" VARCHAR2(128) NOT NULL,
    "RTD_FORMULA" VARCHAR2(255) NULL,
    "IS_DISABLED" NUMBER(1) NULL,
  CONSTRAINT "PK_REAL_TIME_FORMULAS"
    PRIMARY KEY ("ID"),
  CONSTRAINT "IX_REAL_TIME_FORMULAS_COLUMN"
    UNIQUE ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME")
);

CREATE SEQUENCE "RTD"."SQ_REAL_TIME_FORMULAS_ID"
  INCREMENT BY 1
  START WITH 1
  MAXVALUE 1E28
  MINVALUE 1
  NOCYCLE
  CACHE 20
  NOORDER;

CREATE TRIGGER "RTD"."TRG_REAL_TIME_FORMULAS_ID"
  BEFORE INSERT OR UPDATE
  ON "RTD"."REAL_TIME_FORMULAS"
REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW
BEGIN
  IF :new.ID IS NULL THEN
    SELECT SQ_REAL_TIME_FORMULAS_ID.NEXTVAL INTO :new.ID FROM dual;
  END IF;
END;
/

CREATE TABLE "RTD"."REAL_TIME_TABLES" (
    "ID" NUMBER NOT NULL,
    "TABLE_SCHEMA" VARCHAR2(128) NOT NULL,
    "TABLE_NAME" VARCHAR2(128) NOT NULL,
    "LOAD_CODE" VARCHAR2(2000) NULL,
    "IS_HISTORY" NUMBER(1) NULL,
    "IS_DISABLED" NUMBER(1) NULL,
    "TIME_ZONE" VARCHAR2(50) NULL,
    "RTD_INSTANCE_NAME" VARCHAR2(50) NULL,
  CONSTRAINT "PK_REAL_TIME_TABLES"
    PRIMARY KEY ("ID"),
  CONSTRAINT "IX_REAL_TIME_TABLES_TABLE"
    UNIQUE ("TABLE_SCHEMA", "TABLE_NAME")
);

CREATE SEQUENCE "RTD"."SQ_REAL_TIME_TABLES_ID"
  INCREMENT BY 1
  START WITH 1
  MAXVALUE 1E28
  MINVALUE 1
  NOCYCLE
  CACHE 20
  NOORDER;

CREATE TRIGGER "RTD"."TRG_REAL_TIME_TABLES_ID"
  BEFORE INSERT OR UPDATE
  ON "RTD"."REAL_TIME_TABLES"
REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW
BEGIN
  IF :new.ID IS NULL THEN
    SELECT SQ_REAL_TIME_TABLES_ID.NEXTVAL INTO :new.ID FROM dual;
  END IF;
END;
/

CREATE TABLE "RTD"."VFX_STOCK_LIST" (
    "CODE" VARCHAR2(50) NOT NULL,
  CONSTRAINT "PK_VFX_STOCK_LIST"
    PRIMARY KEY ("CODE")
);


CREATE TABLE "RTD"."VFX_HISTORICAL_PRICES" (
    "SYMBOL" VARCHAR2(50) NOT NULL,
    "DATE" DATE NOT NULL,
    "TIME" TIMESTAMP(3) NULL,
    "BID" BINARY_DOUBLE NULL,
    "ASK" BINARY_DOUBLE NULL,
    "OPEN" BINARY_DOUBLE NULL,
    "HIGH" BINARY_DOUBLE NULL,
    "LOW" BINARY_DOUBLE NULL,
    "CLOSE" BINARY_DOUBLE NULL,
    "CHANGE" BINARY_DOUBLE NULL,
    "PERCENT_CHANGE" BINARY_DOUBLE NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
  CONSTRAINT "PK_VFX_HISTORICAL_PRICES"
    PRIMARY KEY ("SYMBOL", "DATE")
);


INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'VFX_HISTORICAL_PRICES', 'SELECT CODE FROM RTD.VFX_STOCK_LIST', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_HISTORICAL_PRICES', 'CODE', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_HISTORICAL_PRICES', 'SYMBOL', '=VFX|Name![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_HISTORICAL_PRICES', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_HISTORICAL_PRICES', 'TIME', '=VFX|Time![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_HISTORICAL_PRICES', 'CHANGE', '=VFX|NetChange![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_HISTORICAL_PRICES', 'PERCENT_CHANGE', '=VFX|PercentChange![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_HISTORICAL_PRICES', 'BID', '=VFX|Bid![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_HISTORICAL_PRICES', 'ASK', '=VFX|Ask![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_HISTORICAL_PRICES', 'OPEN', '=VFX|OpenPrice![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_HISTORICAL_PRICES', 'HIGH', '=VFX|High![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_HISTORICAL_PRICES', 'LOW', '=VFX|Low![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_HISTORICAL_PRICES', 'CLOSE', '=VFX|ClosePrice![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_HISTORICAL_PRICES', 'LAST_UPDATE_TIMESTAMP', '=TimeStamp()', NULL);

CREATE TABLE "RTD"."VFX_LAST_STOCK_QUOTES" (
    "SYMBOL" VARCHAR2(50) NOT NULL,
    "DATE" DATE NULL,
    "TIME" TIMESTAMP(3) NULL,
    "BID" BINARY_DOUBLE NULL,
    "ASK" BINARY_DOUBLE NULL,
    "OPEN" BINARY_DOUBLE NULL,
    "HIGH" BINARY_DOUBLE NULL,
    "LOW" BINARY_DOUBLE NULL,
    "CLOSE" BINARY_DOUBLE NULL,
    "CHANGE" BINARY_DOUBLE NULL,
    "PERCENT_CHANGE" BINARY_DOUBLE NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
  CONSTRAINT "PK_VFX_LAST_STOCK_QUOTES"
    PRIMARY KEY ("SYMBOL")
);


INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'VFX_LAST_STOCK_QUOTES', 'SELECT CODE FROM RTD.VFX_STOCK_LIST', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_LAST_STOCK_QUOTES', 'CODE', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_LAST_STOCK_QUOTES', 'SYMBOL', '=VFX|Name![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_LAST_STOCK_QUOTES', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_LAST_STOCK_QUOTES', 'TIME', '=VFX|Time![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_LAST_STOCK_QUOTES', 'CHANGE', '=VFX|NetChange![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_LAST_STOCK_QUOTES', 'PERCENT_CHANGE', '=VFX|PercentChange![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_LAST_STOCK_QUOTES', 'BID', '=VFX|Bid![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_LAST_STOCK_QUOTES', 'ASK', '=VFX|Ask![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_LAST_STOCK_QUOTES', 'OPEN', '=VFX|OpenPrice![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_LAST_STOCK_QUOTES', 'HIGH', '=VFX|High![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_LAST_STOCK_QUOTES', 'LOW', '=VFX|Low![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_LAST_STOCK_QUOTES', 'CLOSE', '=VFX|ClosePrice![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_LAST_STOCK_QUOTES', 'LAST_UPDATE_TIMESTAMP', '=TimeStamp()', NULL);

CREATE TABLE "RTD"."VFX_STOCK_QUOTES_TICKS" (
    "ID" NUMBER NOT NULL,
    "SYMBOL" VARCHAR2(50) NULL,
    "DATE" DATE NULL,
    "TIME" TIMESTAMP(3) NULL,
    "BID" BINARY_DOUBLE NULL,
    "ASK" BINARY_DOUBLE NULL,
    "OPEN" BINARY_DOUBLE NULL,
    "HIGH" BINARY_DOUBLE NULL,
    "LOW" BINARY_DOUBLE NULL,
    "CLOSE" BINARY_DOUBLE NULL,
    "CHANGE" BINARY_DOUBLE NULL,
    "PERCENT_CHANGE" BINARY_DOUBLE NULL,
  CONSTRAINT "PK_VFX_STOCK_QUOTES_TICKS"
    PRIMARY KEY ("ID")
);

CREATE SEQUENCE "RTD"."SQ_VFX_STOCK_QUOTES_TICKS_ID"
  INCREMENT BY 1
  START WITH 1
  MAXVALUE 1E28
  MINVALUE 1
  NOCYCLE
  CACHE 20
  NOORDER;

CREATE TRIGGER "RTD"."TRG_VFX_STOCK_QUOTES_TICKS_ID"
  BEFORE INSERT OR UPDATE
  ON "RTD"."VFX_STOCK_QUOTES_TICKS"
REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW
BEGIN
  IF :new.ID IS NULL THEN
    SELECT SQ_VFX_STOCK_QUOTES_TICKS_ID.NEXTVAL INTO :new.ID FROM dual;
  END IF;
END;
/


INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'VFX_STOCK_QUOTES_TICKS', 'SELECT CODE FROM RTD.VFX_STOCK_LIST', 1, 1, 'Eastern Standard Time', NULL);

INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_STOCK_QUOTES_TICKS', 'ID', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_STOCK_QUOTES_TICKS', 'CODE', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_STOCK_QUOTES_TICKS', 'SYMBOL', '=VFX|Name![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_STOCK_QUOTES_TICKS', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_STOCK_QUOTES_TICKS', 'TIME', '=VFX|Time![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_STOCK_QUOTES_TICKS', 'CHANGE', '=VFX|NetChange![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_STOCK_QUOTES_TICKS', 'PERCENT_CHANGE', '=VFX|PercentChange![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_STOCK_QUOTES_TICKS', 'BID', '=VFX|Bid![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_STOCK_QUOTES_TICKS', 'ASK', '=VFX|Ask![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_STOCK_QUOTES_TICKS', 'OPEN', '=VFX|OpenPrice![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_STOCK_QUOTES_TICKS', 'HIGH', '=VFX|High![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_STOCK_QUOTES_TICKS', 'LOW', '=VFX|Low![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_STOCK_QUOTES_TICKS', 'CLOSE', '=VFX|ClosePrice![CODE]', NULL);

CREATE TABLE "RTD"."VFX_STOCK_QUOTES_TIME" (
    "SYMBOL" VARCHAR2(50) NOT NULL,
    "DATE" DATE NOT NULL,
    "TIME" TIMESTAMP(3) NOT NULL,
    "BID" BINARY_DOUBLE NULL,
    "ASK" BINARY_DOUBLE NULL,
    "OPEN" BINARY_DOUBLE NULL,
    "HIGH" BINARY_DOUBLE NULL,
    "LOW" BINARY_DOUBLE NULL,
    "CLOSE" BINARY_DOUBLE NULL,
    "CHANGE" BINARY_DOUBLE NULL,
    "PERCENT_CHANGE" BINARY_DOUBLE NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
  CONSTRAINT "PK_VFX_STOCK_QUOTES_TIME"
    PRIMARY KEY ("SYMBOL", "DATE", "TIME")
);


INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'VFX_STOCK_QUOTES_TIME', 'SELECT CODE FROM RTD.VFX_STOCK_LIST', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_STOCK_QUOTES_TIME', 'CODE', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_STOCK_QUOTES_TIME', 'SYMBOL', '=VFX|Name![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_STOCK_QUOTES_TIME', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_STOCK_QUOTES_TIME', 'TIME', '=VFX|Time![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_STOCK_QUOTES_TIME', 'CHANGE', '=VFX|NetChange![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_STOCK_QUOTES_TIME', 'PERCENT_CHANGE', '=VFX|PercentChange![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_STOCK_QUOTES_TIME', 'BID', '=VFX|Bid![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_STOCK_QUOTES_TIME', 'ASK', '=VFX|Ask![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_STOCK_QUOTES_TIME', 'OPEN', '=VFX|OpenPrice![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_STOCK_QUOTES_TIME', 'HIGH', '=VFX|High![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_STOCK_QUOTES_TIME', 'LOW', '=VFX|Low![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_STOCK_QUOTES_TIME', 'CLOSE', '=VFX|ClosePrice![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'VFX_STOCK_QUOTES_TIME', 'LAST_UPDATE_TIMESTAMP', '=TimeStamp()', NULL);

