CREATE SCHEMA IF NOT EXISTS rtd;

CREATE TABLE IF NOT EXISTS rtd.real_time_formulas (
    id serial NOT NULL,
    table_schema varchar(128) NOT NULL,
    table_name varchar(128) NOT NULL,
    column_name varchar(128) NOT NULL,
    rtd_formula varchar(255) NULL,
    is_disabled smallint NULL,
  PRIMARY KEY (id)
);

CREATE UNIQUE INDEX IF NOT EXISTS ix_real_time_formulas_schema_name_column_name ON rtd.real_time_formulas
    USING BTREE (
       table_schema,
       table_name,
       column_name
    );


CREATE TABLE IF NOT EXISTS rtd.real_time_tables (
    id serial NOT NULL,
    table_schema varchar(128) NOT NULL,
    table_name varchar(128) NOT NULL,
    load_code varchar(2000) NULL,
    is_history smallint NULL,
    is_disabled smallint NULL,
    time_zone varchar(50) NULL,
    rtd_instance_name varchar(50) NULL,
  PRIMARY KEY (id)
);

CREATE UNIQUE INDEX IF NOT EXISTS ix_realtimetables_schema_name ON rtd.real_time_tables
    USING BTREE (
       table_schema,
       table_name
    );
    
CREATE TABLE IF NOT EXISTS rtd.es_stock_list (
    code varchar(50) NOT NULL,
  PRIMARY KEY (code)
);

CREATE TABLE IF NOT EXISTS rtd.es_historical_prices (
    symbol varchar(50) NOT NULL,
    date date NOT NULL,
    time time NULL,
    last double precision NULL,
    change double precision NULL,
    percent_change double precision NULL,
    bid double precision NULL,
    ask double precision NULL,
    bid_size integer NULL,
    ask_size integer NULL,
    open double precision NULL,
    high double precision NULL,
    low double precision NULL,
    volume bigint NULL,
    open_int integer NULL,
    trade_price double precision NULL,
    last_update_timestamp timestamp default current_timestamp,
  PRIMARY KEY (symbol, date)
);

INSERT INTO rtd.real_time_tables (table_schema, table_name, load_code, is_history, is_disabled, time_zone, rtd_instance_name) VALUES ('rtd', 'es_historical_prices', 'SELECT code FROM rtd.es_stock_list', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_historical_prices', 'code', NULL, NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_historical_prices', 'symbol', '=RTD("esrtd",,[CODE],"Symbol")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_historical_prices', 'date', '=Date()', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_historical_prices', 'time', '=RTD("esrtd",,[CODE],"Time")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_historical_prices', 'last', '=RTD("esrtd",,[CODE],"Last")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_historical_prices', 'trade_price', '=RTD("esrtd",,[CODE],"TradePrice")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_historical_prices', 'change', '=RTD("esrtd",,[CODE],"Change")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_historical_prices', 'percent_change', '=RTD("esrtd",,[CODE],"% Change")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_historical_prices', 'bid', '=RTD("esrtd",,[CODE],"Bid")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_historical_prices', 'ask', '=RTD("esrtd",,[CODE],"Ask")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_historical_prices', 'bid_size', '=RTD("esrtd",,[CODE],"Bid Size")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_historical_prices', 'ask_size', '=RTD("esrtd",,[CODE],"Ask Size")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_historical_prices', 'open', '=RTD("esrtd",,[CODE],"Open")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_historical_prices', 'high', '=RTD("esrtd",,[CODE],"High")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_historical_prices', 'low', '=RTD("esrtd",,[CODE],"Low")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_historical_prices', 'volume', '=RTD("esrtd",,[CODE],"Volume")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_historical_prices', 'open_int', '=RTD("esrtd",,[CODE],"OpenInt")', NULL);

CREATE TABLE IF NOT EXISTS rtd.es_last_stock_quotes (
    symbol varchar(50) NOT NULL,
    date date NULL,
    time time NULL,
    last double precision NULL,
    change double precision NULL,
    percent_change double precision NULL,
    bid double precision NULL,
    ask double precision NULL,
    bid_size integer NULL,
    ask_size integer NULL,
    open double precision NULL,
    high double precision NULL,
    low double precision NULL,
    volume bigint NULL,
    open_int integer NULL,
    trade_price double precision NULL,
    last_update_timestamp timestamp default current_timestamp,
  PRIMARY KEY (symbol)
);


INSERT INTO rtd.real_time_tables (table_schema, table_name, load_code, is_history, is_disabled, time_zone, rtd_instance_name) VALUES ('rtd', 'es_last_stock_quotes', 'SELECT code FROM rtd.es_stock_list', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_last_stock_quotes', 'code', NULL, NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_last_stock_quotes', 'symbol', '=RTD("esrtd",,[CODE],"Symbol")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_last_stock_quotes', 'date', '=Date()', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_last_stock_quotes', 'time', '=RTD("esrtd",,[CODE],"Time")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_last_stock_quotes', 'last', '=RTD("esrtd",,[CODE],"Last")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_last_stock_quotes', 'trade_price', '=RTD("esrtd",,[CODE],"TradePrice")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_last_stock_quotes', 'change', '=RTD("esrtd",,[CODE],"Change")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_last_stock_quotes', 'percent_change', '=RTD("esrtd",,[CODE],"% Change")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_last_stock_quotes', 'bid', '=RTD("esrtd",,[CODE],"Bid")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_last_stock_quotes', 'ask', '=RTD("esrtd",,[CODE],"Ask")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_last_stock_quotes', 'bid_size', '=RTD("esrtd",,[CODE],"Bid Size")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_last_stock_quotes', 'ask_size', '=RTD("esrtd",,[CODE],"Ask Size")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_last_stock_quotes', 'open', '=RTD("esrtd",,[CODE],"Open")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_last_stock_quotes', 'high', '=RTD("esrtd",,[CODE],"High")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_last_stock_quotes', 'low', '=RTD("esrtd",,[CODE],"Low")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_last_stock_quotes', 'volume', '=RTD("esrtd",,[CODE],"Volume")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_last_stock_quotes', 'open_int', '=RTD("esrtd",,[CODE],"OpenInt")', NULL);

CREATE TABLE IF NOT EXISTS rtd.es_stock_quotes_ticks (
    id serial NOT NULL,
    symbol varchar(50) NOT NULL,
    date date NULL,
    time time NULL,
    last double precision NULL,
    change double precision NULL,
    percent_change double precision NULL,
    bid double precision NULL,
    ask double precision NULL,
    bid_size integer NULL,
    ask_size integer NULL,
    open double precision NULL,
    high double precision NULL,
    low double precision NULL,
    volume bigint NULL,
    open_int integer NULL,
    trade_price double precision NULL,
  PRIMARY KEY (id)
);

INSERT INTO rtd.real_time_tables (table_schema, table_name, load_code, is_history, is_disabled, time_zone, rtd_instance_name) VALUES ('rtd', 'es_stock_quotes_ticks', 'SELECT code FROM rtd.es_stock_list', 1, 1, 'Eastern Standard Time', NULL);

INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_ticks', 'id', NULL, NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_ticks', 'code', NULL, NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_ticks', 'symbol', '=RTD("esrtd",,[CODE],"Symbol")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_ticks', 'date', '=Date()', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_ticks', 'time', '=RTD("esrtd",,[CODE],"Time")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_ticks', 'last', '=RTD("esrtd",,[CODE],"Last")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_ticks', 'trade_price', '=RTD("esrtd",,[CODE],"TradePrice")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_ticks', 'change', '=RTD("esrtd",,[CODE],"Change")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_ticks', 'percent_change', '=RTD("esrtd",,[CODE],"% Change")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_ticks', 'bid', '=RTD("esrtd",,[CODE],"Bid")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_ticks', 'ask', '=RTD("esrtd",,[CODE],"Ask")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_ticks', 'bid_size', '=RTD("esrtd",,[CODE],"Bid Size")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_ticks', 'ask_size', '=RTD("esrtd",,[CODE],"Ask Size")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_ticks', 'open', '=RTD("esrtd",,[CODE],"Open")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_ticks', 'high', '=RTD("esrtd",,[CODE],"High")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_ticks', 'low', '=RTD("esrtd",,[CODE],"Low")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_ticks', 'volume', '=RTD("esrtd",,[CODE],"Volume")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_ticks', 'open_int', '=RTD("esrtd",,[CODE],"OpenInt")', NULL);

CREATE TABLE IF NOT EXISTS rtd.es_stock_quotes_time (
    symbol varchar(50) NOT NULL,
    date date NOT NULL,
    time time NOT NULL,
    last double precision NULL,
    change double precision NULL,
    percent_change double precision NULL,
    bid double precision NULL,
    ask double precision NULL,
    bid_size integer NULL,
    ask_size integer NULL,
    open double precision NULL,
    high double precision NULL,
    low double precision NULL,
    volume bigint NULL,
    open_int integer NULL,
    trade_price double precision NULL,
    last_update_timestamp timestamp default current_timestamp,
  PRIMARY KEY (symbol, date, time)
);

INSERT INTO rtd.real_time_tables (table_schema, table_name, load_code, is_history, is_disabled, time_zone, rtd_instance_name) VALUES ('rtd', 'es_stock_quotes_time', 'SELECT code FROM rtd.es_stock_list', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_time', 'code', NULL, NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_time', 'symbol', '=RTD("esrtd",,[CODE],"Symbol")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_time', 'date', '=Date()', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_time', 'time', '=RTD("esrtd",,[CODE],"Time")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_time', 'last', '=RTD("esrtd",,[CODE],"Last")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_time', 'trade_price', '=RTD("esrtd",,[CODE],"TradePrice")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_time', 'change', '=RTD("esrtd",,[CODE],"Change")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_time', 'percent_change', '=RTD("esrtd",,[CODE],"% Change")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_time', 'bid', '=RTD("esrtd",,[CODE],"Bid")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_time', 'ask', '=RTD("esrtd",,[CODE],"Ask")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_time', 'bid_size', '=RTD("esrtd",,[CODE],"Bid Size")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_time', 'ask_size', '=RTD("esrtd",,[CODE],"Ask Size")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_time', 'open', '=RTD("esrtd",,[CODE],"Open")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_time', 'high', '=RTD("esrtd",,[CODE],"High")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_time', 'low', '=RTD("esrtd",,[CODE],"Low")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_time', 'volume', '=RTD("esrtd",,[CODE],"Volume")', NULL);
INSERT INTO rtd.real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES ('rtd', 'es_stock_quotes_time', 'open_int', '=RTD("esrtd",,[CODE],"OpenInt")', NULL);

