CREATE TABLE IF NOT EXISTS tws_last_option_data (
    code varchar(255) NOT NULL,
    datetime timestamp NULL,
    date date NULL,
    time time NULL,
    last double NULL,
    last_size integer NULL,
    bid double NULL,
    ask double NULL,
    bid_size integer NULL,
    ask_size integer NULL,
    high double NULL,
    low double NULL,
    close double NULL,
    volume bigint NULL,
    underlying_price double NULL,
    model_price double NULL,
    implied_vol double NULL,
    bid_implied_vol double NULL,
    ask_implied_vol double NULL,
    last_implied_vol double NULL,
    bid_delta double NULL,
    ask_delta double NULL,
    last_delta double NULL,
    delta double NULL,
    gamma double NULL,
    theta double NULL,
    vega double NULL,
    pv_dividend double NULL,
    last_update_timestamp timestamp default current_timestamp,
  PRIMARY KEY (code)
);

INSERT INTO real_time_tables (table_schema, table_name, load_code, is_history, is_disabled, time_zone, rtd_instance_name) VALUES (NULL, 'tws_last_option_data', 'SELECT tick_id, code FROM tws_stock_list WHERE code LIKE ''%_OPT_20%''', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'tick_id', NULL, NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'code', NULL, NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'req', '=S|tik!''id[TICK_ID]?req?[CODE]''', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'datetime', '=DateTime()', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'date', '=Date()', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'time', '=Time()', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'last', '=S|tik!id[TICK_ID]?last', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'last_size', '=S|tik!id[TICK_ID]?lastSize', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'bid', '=S|tik!id[TICK_ID]?bid', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'ask', '=S|tik!id[TICK_ID]?ask', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'bid_size', '=S|tik!id[TICK_ID]?bidSize', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'ask_size', '=S|tik!id[TICK_ID]?askSize', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'high', '=S|tik!id[TICK_ID]?high', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'low', '=S|tik!id[TICK_ID]?low', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'close', '=S|tik!id[TICK_ID]?close', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'volume', '=S|tik!id[TICK_ID]?volume', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'underlying_price', '=S|tik!id[TICK_ID]?modelUndPrice', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'model_price', '=S|tik!id[TICK_ID]?modelPrice', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'implied_vol', '=S|tik!id[TICK_ID]?modelVolatility', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'bid_implied_vol', '=S|tik!id[TICK_ID]?bidImpliedVol', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'ask_implied_vol', '=S|tik!id[TICK_ID]?askImpliedVol', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'last_implied_vol', '=S|tik!id[TICK_ID]?lastImpliedVol', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'bid_delta', '=S|tik!id[TICK_ID]?bidDelta', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'ask_delta', '=S|tik!id[TICK_ID]?askDelta', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'last_delta', '=S|tik!id[TICK_ID]?lastDelta', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'delta', '=S|tik!id[TICK_ID]?modelDelta', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'gamma', '=S|tik!id[TICK_ID]?modelGamma', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'theta', '=S|tik!id[TICK_ID]?modelTheta', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'vega', '=S|tik!id[TICK_ID]?modelVega', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'pv_dividend', '=S|tik!id[TICK_ID]?pvDividend', NULL);

